========
Examples
========

This section contains examples for using various TomoPy functions and plugins
from other packages.

.. toctree::
   :titlesonly:
   :hidden:

   examples/align
   examples/ptycho
   examples/scan
   examples/tomo
